==> haskell-network-simple-0.4.5-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-7GxnejiMTxB7y6UNdshzof
key:                  network-simple-0.4.5-7GxnejiMTxB7y6UNdshzof
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  97860ea83ce4b4175935d1506d67d7a9
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-7GxnejiMTxB7y6UNdshzof
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    network-3.1.2.7-CS681TPv1I76Ct75uHBcbk
    network-bsd-2.8.1.0-CRqv75Jun6wDxAOS6f28mq
    safe-exceptions-0.1.7.2-J2KhznimyCAE8WdYoAkLF8
    socks-0.6.1-16TZHnT3Y79D8vVgp5S4Ae transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-simple-0.4.5-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-5fOqGidLkKySvWkCOY2EU
key:                  network-simple-0.4.5-5fOqGidLkKySvWkCOY2EU
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  96b511e8af359a7cda05ac11d96debc7
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-5fOqGidLkKySvWkCOY2EU
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    network-3.1.2.7-8MYdqm3OoEgFMARhN0ME57
    network-bsd-2.8.1.0-2IuohH69nx54f1gO09Vgq
    safe-exceptions-0.1.7.3-9Z3tMYHFt5EDmmLLfsdbOy
    socks-0.6.1-6t4qwosjkcI3lip1phFCkt transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
